@@ -399,28 +399,26 @@ get_date_string_for_day (GDateTime *day)
     }
   else
     {
-      gchar *event_month;
+      const gchar *event_month;
       gchar *event_month_names [] = {
-        N_("New Event on January"),
-        N_("New Event on February"),
-        N_("New Event on March"),
-        N_("New Event on April"),
-        N_("New Event on May"),
-        N_("New Event on June"),
-        N_("New Event on July"),
-        N_("New Event on August"),
-        N_("New Event on September"),
-        N_("New Event on October"),
-        N_("New Event on November"),
-        N_("New Event on December"),
+        /* Translators: %d is the numeric day of month */
+        N_("New Event on January %d"),
+        N_("New Event on February %d"),
+        N_("New Event on March %d"),
+        N_("New Event on April %d"),
+        N_("New Event on May %d"),
+        N_("New Event on June %d"),
+        N_("New Event on July %d"),
+        N_("New Event on August %d"),
+        N_("New Event on September %d"),
+        N_("New Event on October %d"),
+        N_("New Event on November %d"),
+        N_("New Event on December %d"),
         NULL
       };
 
       event_month = gettext (event_month_names [g_date_time_get_month (day) - 1]);
-      /* Translators: %1$s is the event month (e.g. "New Event on December") and %2$d is the numeric day of month */
-      string_for_date = g_strdup_printf (_("%1$s %2$d"),
-                                         event_month,
-                                         g_date_time_get_day_of_month (day));
+      string_for_date = g_strdup_printf (event_month, g_date_time_get_day_of_month (day));
     }
 
   return string_for_date;
@@ -538,7 +536,9 @@ on_source_changed (GcalManager         *manager,
   /* If the calendar changed from/to read-only, we add or remove it here */
   if (!gcal_manager_is_client_writable (self->manager, source))
     {
-      gtk_container_remove (GTK_CONTAINER (self->calendars_listbox), row);
+      if (row)
+        gtk_container_remove (GTK_CONTAINER (self->calendars_listbox), row);
+
       return;
     }
   else if (!row)
@@ -779,7 +779,28 @@ gcal_quick_add_popover_set_property (GObject      *object,
       break;
 
     case PROP_MANAGER:
-      gcal_quick_add_popover_set_manager (self, g_value_get_object (value));
+      if (g_set_object (&self->manager, g_value_get_object (value)))
+        {
+          GcalManager *manager;
+          GList *sources, *l;
+
+          /* Add currently leaded sources */
+          manager = self->manager;
+          sources = gcal_manager_get_sources_connected (manager);
+
+          for (l = sources; l != NULL; l = g_list_next (l))
+            on_source_added (manager, l->data, gcal_manager_is_client_writable (manager, l->data), self);
+
+          g_list_free (sources);
+
+          /* Connect to the manager signals and keep the list updates */
+          g_signal_connect (manager, "source-added", G_CALLBACK (on_source_added), self);
+          g_signal_connect (manager, "source-changed", G_CALLBACK (on_source_changed), self);
+          g_signal_connect (manager, "source-removed", G_CALLBACK (on_source_removed), self);
+          g_signal_connect_swapped (manager, "notify::default-calendar", G_CALLBACK (update_default_calendar_row), self);
+
+          g_object_notify (G_OBJECT (self), "manager");
+        }
       break;
 
     default:
@@ -905,41 +926,6 @@ gcal_quick_add_popover_new (void)
   return g_object_new (GCAL_TYPE_QUICK_ADD_POPOVER, NULL);
 }
 
-/**
- * gcal_quick_add_popover_set_manager:
- * @self: a #GcalQuickAddPopover
- * @manager: a #GcalManager
- *
- * Sets the manager of the popover.
- */
-void
-gcal_quick_add_popover_set_manager (GcalQuickAddPopover *self,
-                                    GcalManager         *manager)
-{
-  g_return_if_fail (GCAL_IS_QUICK_ADD_POPOVER (self));
-
-  if (g_set_object (&self->manager, manager))
-    {
-      GList *sources, *l;
-
-      /* Add currently leaded sources */
-      sources = gcal_manager_get_sources_connected (manager);
-
-      for (l = sources; l != NULL; l = g_list_next (l))
-        on_source_added (manager, l->data, gcal_manager_is_client_writable (manager, l->data), self);
-
-      g_list_free (sources);
-
-      /* Connect to the manager signals and keep the list updates */
-      g_signal_connect (manager, "source-added", G_CALLBACK (on_source_added), self);
-      g_signal_connect (manager, "source-changed", G_CALLBACK (on_source_changed), self);
-      g_signal_connect (manager, "source-removed", G_CALLBACK (on_source_removed), self);
-      g_signal_connect_swapped (manager, "notify::default-calendar", G_CALLBACK (update_default_calendar_row), self);
-
-      g_object_notify (G_OBJECT (self), "manager");
-    }
-}
-
 /**
  * gcal_quick_add_popover_get_date_start:
  * @self: a #GcalQuickAddPopover
